@@ -26,14 +26,12 @@ class Filter : public Class<Filter, const Ticket&> {
   virtual ~Filter() = default;
 
   virtual an<Translation> Apply(an<Translation> translation,
-                                        CandidateList* candidates) = 0;
+                                CandidateList* candidates) = 0;
+
+  virtual bool AppliesToSegment(Segment* segment) { return true; }
 
-  virtual bool AppliesToSegment(Segment* segment) {
-    return true;
-  }
- 
   string name_space() const { return name_space_; }
- 
+
  protected:
   Engine* engine_;
   string name_space_;
