@@ -15,8 +15,7 @@ class HistoryTranslator : public Translator {
  public:
   HistoryTranslator(const Ticket& ticket);
 
-  virtual an<Translation> Query(const string& input,
-                                const Segment& segment);
+  virtual an<Translation> Query(const string& input, const Segment& segment);
 
  protected:
   string tag_;
