@@ -5,7 +5,7 @@
 // 2013-07-02 GONG Chen <chen.sst@gmail.com>
 //
 #include <sstream>
-#include <boost/algorithm/string.hpp>
+#include <algorithm>
 #include <rime/context.h>
 #include <rime/engine.h>
 #include <rime/key_event.h>
@@ -17,19 +17,18 @@ void ShapeFormatter::Format(string* text) {
   if (!engine_->context()->get_option("full_shape")) {
     return;
   }
-  if (boost::all(*text, !boost::is_from_range('\x20', '\x7e'))) {
+  if (std::all_of(text->cbegin(), text->cend(),
+                  [](auto ch) { return (ch < 0x20 || ch > 0x7e); })) {
     return;
   }
   std::ostringstream oss;
   for (char ch : *text) {
     if (ch == 0x20) {
       oss << "\xe3\x80\x80";
-    }
-    else if (ch > 0x20 && ch <= 0x7e) {
+    } else if (ch > 0x20 && ch <= 0x7e) {
       ch -= 0x20;
-      oss << '\xef' << char('\xbc' + ch / 0x40) <<  char('\x80' + ch % 0x40);
-    }
-    else {
+      oss << '\xef' << char('\xbc' + ch / 0x40) << char('\x80' + ch % 0x40);
+    } else {
       oss << ch;
     }
   }
