@@ -17,7 +17,7 @@ class Opencc;
 
 class Simplifier : public Filter, TagMatching {
  public:
-  explicit Simplifier(const Ticket& ticket);
+  Simplifier(const Ticket& ticket, an<Opencc> opencc);
 
   virtual an<Translation> Apply(an<Translation> translation,
                                 CandidateList* candidates);
@@ -29,17 +29,14 @@ class Simplifier : public Filter, TagMatching {
  protected:
   enum TipsLevel { kTipsNone, kTipsChar, kTipsAll };
 
-  void Initialize();
   void PushBack(const an<Candidate>& original,
                 CandidateQueue* result,
                 const string& simplified);
 
-  bool initialized_ = false;
-  the<Opencc> opencc_;
+  an<Opencc> opencc_;
   // settings
   TipsLevel tips_level_ = kTipsNone;
   string option_name_;
-  string opencc_config_;
   set<string> excluded_types_;
   bool show_in_comment_ = false;
   bool inherit_comment_ = true;
@@ -47,6 +44,15 @@ class Simplifier : public Filter, TagMatching {
   bool random_ = false;
 };
 
+class SimplifierComponent : public Simplifier::Component {
+ public:
+  SimplifierComponent();
+  Simplifier* Create(const Ticket& ticket);
+
+ private:
+  hash_map<string, weak<Opencc>> opencc_map_;
+};
+
 }  // namespace rime
 
 #endif  // RIME_SIMPLIFIER_H_
