@@ -2000,7 +2000,7 @@ static const key_entry keys_by_name[] = {
     {0x0000ff, 1270},  {0x0000a5, 468},   {0x00007a, 383},   {0x0001bf, 1456},
     {0x0001bc, 1430},  {0x0001be, 1449}};
 
-RIME_API int RimeGetModifierByName(const char* name) {
+RIME_DLL int RimeGetModifierByName(const char* name) {
   const int n = sizeof(modifier_name) / sizeof(const char*);
   if (!name)
     return 0;
@@ -2012,7 +2012,7 @@ RIME_API int RimeGetModifierByName(const char* name) {
   return 0;
 }
 
-RIME_API const char* RimeGetModifierName(int modifier) {
+RIME_DLL const char* RimeGetModifierName(int modifier) {
   const int n = sizeof(modifier_name) / sizeof(const char*);
   for (int i = 0; i < n && modifier != 0; ++i) {
     if ((modifier & 1) != 0) {
@@ -2023,7 +2023,7 @@ RIME_API const char* RimeGetModifierName(int modifier) {
   return NULL;
 }
 
-RIME_API int RimeGetKeycodeByName(const char* name) {
+RIME_DLL int RimeGetKeycodeByName(const char* name) {
   for (const key_entry* p = keys_by_keyval; p->keyval != XK_VoidSymbol; ++p) {
     if (!strcmp(name, key_names + p->offset)) {
       return p->keyval;
@@ -2032,7 +2032,7 @@ RIME_API int RimeGetKeycodeByName(const char* name) {
   return XK_VoidSymbol;
 }
 
-RIME_API const char* RimeGetKeyName(int keycode) {
+RIME_DLL const char* RimeGetKeyName(int keycode) {
   const int n = sizeof(keys_by_name) / sizeof(const key_entry);
   for (int i = 0; i < n; ++i) {
     if (keycode == keys_by_name[i].keyval) {
