@@ -110,6 +110,10 @@ bool InstallationUpdate::Run(Deployer* deployer) {
       deployer->sync_dir = user_data_path / "sync";
     }
     LOG(INFO) << "sync dir: " << deployer->sync_dir;
+    bool backup_config_files;
+    if (config.GetBool("backup_config_files", &backup_config_files)) {
+      deployer->backup_config_files = backup_config_files;
+    }
     if (config.GetString("distribution_code_name", &last_distro_code_name)) {
       LOG(INFO) << "previous distribution: " << last_distro_code_name;
     }
@@ -535,6 +539,10 @@ static bool IsCustomizedCopy(const path& file_path) {
 }
 
 bool BackupConfigFiles::Run(Deployer* deployer) {
+  if (!deployer->backup_config_files) {
+    LOG(INFO) << "skip backing up config files because it's disabled.";
+    return true;
+  }
   LOG(INFO) << "backing up config files.";
   const path user_data_path(deployer->user_data_dir);
   if (!fs::exists(user_data_path))
